@@ -24,6 +24,9 @@
     rownames(tbl) <- rn[c(TRUE, !is.null(x$CA$imaginary.chi), !is.null(x$pCCA),
                           !is.null(x$CCA),  !is.null(x$CA),
                           !is.null(x$CA$imaginary.chi))]
+    ## Remove "Proportion" if only one component
+    if (is.null(x$CCA) && is.null(x$pCCA))
+        tbl <- tbl[,-2]
     printCoefmat(tbl, digits = digits, na.print = "")
     cat("Inertia is", x$inertia, "\n")
     if (!is.null(x$CCA$alias))
@@ -37,11 +40,11 @@
         cat(length(sp.na), "species",
             ifelse(length(sp.na)==1, "(variable)", "(variables)"),
             "deleted due to missingness\n")
-    if (!is.null(x$CCA)) {
+    if (!is.null(x$CCA) && x$CCA$rank > 0) {
         cat("\nEigenvalues for constrained axes:\n")
         print(x$CCA$eig, digits = digits, ...)
     }
-    if (!is.null(x$CA)) {
+    if (!is.null(x$CA) && x$CA$rank > 0) {
         ax.lim <- 8
         ax.trig <- 16
         cat("\nEigenvalues for unconstrained axes:\n")
